==> QupZilla-2.0.1.tar.xz: QupZilla-2.0.1/src/plugins/PIM/translations/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="59"/>
        <source>Last Name</source>
        <translation>Achternaam</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>First Name</source>
        <translation>Voornaam</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>E-mail</source>
        <translation>E-mailadres</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>Mobile</source>
        <translation>Mobiel telefoonnummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Phone</source>
        <translation>Vast telefoonnummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>City</source>
        <translation>Stad</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>ZIP Code</source>
        <translation>Postcode</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>State/Region</source>
        <translation>Staat/Provincie</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>Country</source>
        <translation>Land</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Home Page</source>
        <translation>Website</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Custom 1</source>
        <translation>Aangepast 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 2</source>
        <translation>Aangepast 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 3</source>
        <translation>Aangepast 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="114"/>
        <source>Insert Personal Information</source>
        <translation>Vul hier persoonlijke informatie in</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="135"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>PIM-instellingen</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Persoonlijke informatiebeheerder&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>Uw persoonlijke informatie die zal worden gebruikt op websites.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Voornaam:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Achternaam:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>E-mailadres:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Vast telefoonnummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Mobiel telefoonnummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Stad:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Postcode:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Staat/Provincie:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>Land:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Website:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Aangepast 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Aangepast 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Aangepast 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Tip:&lt;/b&gt; druk op CTRL+ENTER om formuliervelden automatisch in te vullen met de door u opgegeven persoonlijke informatie.</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/PIM/translations/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="59"/>
        <source>Last Name</source>
        <translation>Achternaam</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>First Name</source>
        <translation>Voornaam</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>E-mail</source>
        <translation>E-mailadres</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>Mobile</source>
        <translation>Mobiel nummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Phone</source>
        <translation>Vast nummer</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>City</source>
        <translation>Stad</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>ZIP Code</source>
        <translation>Postcode</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>State/Region</source>
        <translation>Staat/Provincie</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>Country</source>
        <translation>Land</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Home Page</source>
        <translation>Website</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Custom 1</source>
        <translation>Aangepast 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 2</source>
        <translation>Aangepast 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 3</source>
        <translation>Aangepast 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="114"/>
        <source>Insert Personal Information</source>
        <translation>Vul hier persoonlijke informatie in</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="135"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>PIM-instellingen</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Persoonlijke informatiebeheerder&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>Uw persoonlijke informatie die zal worden gebruikt op websites.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Voornaam:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Achternaam:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>E-mailadres:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Vast nummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Mobiel nummer:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Stad:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Postcode:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Staat/Provincie:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>Land:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Website:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Aangepast 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Aangepast 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Aangepast 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Tip:&lt;/b&gt; druk op CTRL+ENTER om formuliervelden automatisch in te vullen met de door u opgegeven persoonlijke informatie.</translation>
    </message>
</context>
</TS>
